@@ -134,16 +134,41 @@ function startImport($backupFilePath) {
     $stmt->execute([$importId, AUTH_USER, $backupFilePath]);
     
     // Start import in background
-    $command = "php " . dirname(__DIR__) . "/scripts/run-cpanel-import.php " . 
+    $scriptPath = "/root/whp/scripts/run-cpanel-import.php";
+    
+    // Check if script exists
+    if (!file_exists($scriptPath)) {
+        return ['success' => false, 'error' => 'Import script not found: ' . $scriptPath];
+    }
+    
+    // Build command with proper logging
+    $logFile = "/var/log/cpanel-import-{$importId}.log";
+    $command = "php " . escapeshellarg($scriptPath) . " " . 
                escapeshellarg($importId) . " " . 
                escapeshellarg(AUTH_USER) . " " . 
-               escapeshellarg($backupFilePath) . " > /dev/null 2>&1 &";
+               escapeshellarg($backupFilePath) . " > " . escapeshellarg($logFile) . " 2>&1 &";
     
-    exec($command);
+    // Log the command for debugging
+    error_log("Starting cPanel import with command: " . $command);
+    
+    // Execute command and capture return value
+    $output = [];
+    $returnCode = 0;
+    exec($command, $output, $returnCode);
+    
+    // Check if command started successfully
+    if ($returnCode !== 0) {
+        error_log("Failed to start cPanel import process. Return code: " . $returnCode);
+        return ['success' => false, 'error' => 'Failed to start import process'];
+    }
+    
+    // Log successful start
+    error_log("cPanel import process started successfully for import ID: " . $importId);
     
     return [
         'success' => true,
-        'import_id' => $importId
+        'import_id' => $importId,
+        'log_file' => $logFile
     ];
 }
 
