@@ -14,6 +14,8 @@ class CpanelBackupImporter {
     private $username;
     private $importLog = [];
     private $siteGroups = [];
+    private $mysqlMgmt;
+    private $powerDNS;
     
     public function __construct($pdo, $username) {
         $this->pdo = $pdo;
@@ -540,18 +542,94 @@ class CpanelBackupImporter {
      * Create a WHP site entry
      */
     private function createWhpSite($domain, $domainData) {
-        // This would integrate with your existing site creation system
-        // Placeholder for actual WHP site creation logic
+        // First ensure we have a default container type
+        $stmt = $this->pdo->prepare("SELECT id FROM whp.container_types WHERE name = 'PHP 8.2' AND active = 1 LIMIT 1");
+        $stmt->execute();
+        $containerType = $stmt->fetch();
+        
+        if (!$containerType) {
+            // Use first active container type
+            $stmt = $this->pdo->prepare("SELECT id FROM whp.container_types WHERE active = 1 LIMIT 1");
+            $stmt->execute();
+            $containerType = $stmt->fetch();
+            
+            if (!$containerType) {
+                throw new Exception("No active container types available");
+            }
+        }
+        
+        $containerTypeId = $containerType['id'];
+        
+        // Check if domain exists in WHP
+        $stmt = $this->pdo->prepare("SELECT id, domain_name FROM whp.domains WHERE domain_name = ? AND username = ?");
+        $stmt->execute([$domain, $this->username]);
+        $domainRow = $stmt->fetch();
+        
+        if (!$domainRow) {
+            // Create domain first
+            $stmt = $this->pdo->prepare("
+                INSERT INTO whp.domains (domain_name, username, active, created_at) 
+                VALUES (?, ?, 1, NOW())
+            ");
+            $stmt->execute([$domain, $this->username]);
+            $domainId = $this->pdo->lastInsertId();
+        } else {
+            $domainId = $domainRow['id'];
+        }
+        
+        // Create site directory
+        $siteDir = '/docker/users/' . $this->username . '/' . $domain;
+        if (!is_dir($siteDir)) {
+            mkdir($siteDir, 0755, true);
+            
+            // Set ownership
+            $uid = trim(shell_exec("id -u " . escapeshellarg($this->username)));
+            $gid = trim(shell_exec("id -g " . escapeshellarg($this->username)));
+            if (is_numeric($uid) && is_numeric($gid)) {
+                shell_exec("chown -R {$uid}:{$gid} " . escapeshellarg($siteDir));
+            }
+        }
+        
+        // Insert site into database with proper structure
+        $siteName = $domain . " (Imported from cPanel)";
         
         $stmt = $this->pdo->prepare("
-            INSERT INTO sites (username, domain, container_name, created_at) 
-            VALUES (?, ?, ?, NOW())
+            INSERT INTO whp.sites (
+                site_name, 
+                primary_domain_id, 
+                username, 
+                container_type_id, 
+                container_count, 
+                cpu_per_container, 
+                memory_per_container, 
+                user_variables, 
+                auto_recreate_on_update,
+                created_at
+            ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, NOW())
         ");
         
-        $containerName = $domain . '-01';
-        $stmt->execute([$this->username, $domain, $containerName]);
+        $stmt->execute([
+            $siteName,
+            $domainId,
+            $this->username,
+            $containerTypeId,
+            1, // container_count
+            0.25, // cpu_per_container
+            256, // memory_per_container
+            '{}', // user_variables
+            0 // auto_recreate_on_update
+        ]);
         
-        return $this->pdo->lastInsertId();
+        $siteId = $this->pdo->lastInsertId();
+        
+        // Insert into site_domains table for relationship
+        $stmt = $this->pdo->prepare("
+            INSERT INTO whp.site_domains (site_id, domain_id, is_primary) 
+            VALUES (?, ?, 1)
+        ");
+        $stmt->execute([$siteId, $domainId]);
+        
+        return $siteId;
     }
     
     
@@ -631,29 +709,40 @@ class CpanelBackupImporter {
     }
     
     /**
-     * Import a single database
+     * Import a single database using WHP's mysqlmgmt class
      */
     private function importDatabase($originalDbName, $sqlFile) {
+        // Initialize mysqlmgmt if not already done
+        if (!isset($this->mysqlMgmt)) {
+            require_once('/docker/whp/web/libs/mysqlmgmt.php');
+            $this->mysqlMgmt = new mysqlmgmt();
+        }
+        
         // Generate WHP-compatible database name
         $random = substr(md5(uniqid()), 0, 8);
         $whpDbName = $this->username . '_' . preg_replace('/[^a-zA-Z0-9]/', '', $originalDbName) . '_' . $random;
         
         try {
-            // Create database
-            $stmt = $this->pdo->prepare("CREATE DATABASE " . $whpDbName);
-            $stmt->execute();
+            // Create database using WHP's method
+            $result = $this->mysqlMgmt->createDatabase($whpDbName, $this->username);
             
-            // Import SQL file
-            $command = "mysql " . escapeshellarg($whpDbName) . " < " . escapeshellarg($sqlFile);
-            $output = [];
-            $returnCode = 0;
-            
-            exec($command, $output, $returnCode);
-            
-            if ($returnCode === 0) {
-                $this->log("Database imported: " . $originalDbName . " -> " . $whpDbName);
+            if ($result['status'] === '0') {
+                $this->log("Database created: " . $originalDbName . " -> " . $whpDbName);
+                
+                // Import SQL file
+                $command = "mysql " . escapeshellarg($whpDbName) . " < " . escapeshellarg($sqlFile);
+                $output = [];
+                $returnCode = 0;
+                
+                exec($command, $output, $returnCode);
+                
+                if ($returnCode === 0) {
+                    $this->log("Database imported: " . $originalDbName . " -> " . $whpDbName);
+                } else {
+                    throw new Exception("Failed to import database: " . implode("\n", $output));
+                }
             } else {
-                throw new Exception("Failed to import database: " . implode("\n", $output));
+                $this->log("Failed to create database " . $originalDbName . ": " . $result['msg'], 'error');
             }
             
         } catch (Exception $e) {
@@ -671,9 +760,15 @@ class CpanelBackupImporter {
     }
     
     /**
-     * Create a MySQL user with WHP naming convention
+     * Create a MySQL user with WHP naming convention using mysqlmgmt class
      */
     private function createMysqlUser($grant) {
+        // Initialize mysqlmgmt if not already done
+        if (!isset($this->mysqlMgmt)) {
+            require_once('/docker/whp/web/libs/mysqlmgmt.php');
+            $this->mysqlMgmt = new mysqlmgmt();
+        }
+        
         $originalUsername = $grant['username'];
         
         // Generate WHP-compatible username
@@ -682,10 +777,14 @@ class CpanelBackupImporter {
         $password = bin2hex(random_bytes(16));
         
         try {
-            $stmt = $this->pdo->prepare("CREATE USER ? IDENTIFIED BY ?");
-            $stmt->execute([$whpUsername, $password]);
+            // Create user using WHP's method
+            $result = $this->mysqlMgmt->createMySQLUser($whpUsername, $password);
             
-            $this->log("MySQL user created: " . $originalUsername . " -> " . $whpUsername);
+            if ($result['status'] === '0') {
+                $this->log("MySQL user created: " . $originalUsername . " -> " . $whpUsername);
+            } else {
+                $this->log("Failed to create MySQL user " . $originalUsername . ": " . $result['msg'], 'error');
+            }
             
         } catch (Exception $e) {
             $this->log("Failed to create MySQL user " . $originalUsername . ": " . $e->getMessage(), 'error');
@@ -693,12 +792,18 @@ class CpanelBackupImporter {
     }
     
     /**
-     * Create DNS records for imported domains
+     * Create DNS records for imported domains using PowerDNS integration
      */
     private function createDnsRecords($domains) {
-        if (!$this->isDnsManagerAvailable()) {
-            $this->log("DNS manager not available - skipping DNS record creation", 'warning');
-            return;
+        // Initialize PowerDNS integration if not already done
+        if (!isset($this->powerDNS)) {
+            try {
+                require_once('/docker/whp/web/libs/pdns-integration.php');
+                $this->powerDNS = new PowerDNSIntegration($this->pdo);
+            } catch (Exception $e) {
+                $this->log("PowerDNS integration not available - skipping DNS record creation: " . $e->getMessage(), 'warning');
+                return;
+            }
         }
         
         foreach ($this->siteGroups as $docRoot => $siteGroup) {
@@ -716,35 +821,47 @@ class CpanelBackupImporter {
     }
     
     /**
-     * Create DNS records for a specific domain
+     * Create DNS records for a specific domain using PowerDNS
      */
     private function createDomainDnsRecords($domain) {
         try {
-            // Check if DNS manager is available
-            if (!file_exists('/home/jknapp/code/whp/web-files/includes/dns_manager.php')) {
-                $this->log("DNS manager file not found - skipping DNS for: " . $domain, 'warning');
+            // Check if domain zone exists
+            $zoneExists = false;
+            $zones = $this->powerDNS->getZones();
+            foreach ($zones as $zone) {
+                if ($zone['name'] === $domain . '.') {
+                    $zoneExists = true;
+                    break;
+                }
+            }
+            
+            if (!$zoneExists) {
+                // Create zone
+                $result = $this->powerDNS->createZone($domain, $this->username);
+                if ($result) {
+                    $this->log("DNS zone created for: $domain");
+                } else {
+                    $this->log("Failed to create DNS zone for: $domain", 'warning');
+                    return;
+                }
+            }
+            
+            // Get server IP
+            $serverIp = $this->getServerIp();
+            if (!$serverIp) {
+                $this->log("Could not determine server IP - skipping DNS records for: $domain", 'warning');
                 return;
             }
             
-            require_once '/home/jknapp/code/whp/web-files/includes/dns_manager.php';
-            
-            // Get server IP (this should be configurable)
-            $serverIp = $this->getServerIp();
-            
-            // Create basic DNS records
-            $records = [
-                ['name' => $domain, 'type' => 'A', 'content' => $serverIp],
-                ['name' => 'www.' . $domain, 'type' => 'A', 'content' => $serverIp],
-                ['name' => $domain, 'type' => 'MX', 'content' => 'mail.' . $domain, 'priority' => 10]
-            ];
-            
-            foreach ($records as $record) {
-                $result = createDnsRecord($domain, $record['name'], $record['type'], $record['content'], $record['priority'] ?? null);
-                if ($result) {
-                    $this->log("Created DNS record: " . $record['name'] . " " . $record['type'] . " " . $record['content']);
-                } else {
-                    $this->log("Failed to create DNS record: " . $record['name'] . " " . $record['type'], 'warning');
-                }
+            // Add A records pointing to server IP
+            try {
+                $this->powerDNS->addRecord($domain, $domain, 'A', $serverIp, 300);
+                $this->log("Created DNS A record: $domain -> $serverIp");
+                
+                $this->powerDNS->addRecord($domain, 'www.' . $domain, 'A', $serverIp, 300);
+                $this->log("Created DNS A record: www.$domain -> $serverIp");
+            } catch (Exception $e) {
+                $this->log("Failed to create DNS A records for $domain: " . $e->getMessage(), 'warning');
             }
             
         } catch (Exception $e) {
